==> rioja_0.5-2.tar.gz: rioja/man/utils.Rd <==
\name{utils}
\alias{make.dummy}
\alias{dummy2factor}
\alias{dot}
\alias{dot.default}
\alias{dot.data.frame}
\alias{Hill.N2}
\alias{site.summ}
\alias{sp.summ}
\alias{write.list.Excel}

\title{Utility functions. }
\description{
Utility functions to perform simple computations, transformations, formatting etc.
}
\usage{
make.dummy(fact)

dummy2factor(x)

Hill.N2(df, margin=2)

site.summ(y, max.cut=c(2, 5, 10, 20))

sp.summ(y, n.cut=c(5, 10, 20))

write.list.Excel(x, fName)

}
\arguments{
  \item{fact}{ a factor to convert to a matrix of dummy variables. }
  \item{x}{ a matrix or data frame of dummy variables to convert to a factor, 
        or a list to save as an Excel file. }
  \item{df}{ a data frame of species abundance data. }
  \item{margin}{ margin to calculate over: 1 = by rows, 2 = by columns. }
  \item{fName}{ file name for Excel file. }
  \item{y}{ data frame or matrix of species by sites data. }
  \item{n.cut}{ cut levels of abundance for species summary (see below). }
  \item{max.cut}{ cut levels of occurence for species sumamry. }
}

\details{
  Function \code{make.dummy} converts a factor into a matrix of dummy (1/0) variables. \code{dummy2factor} converts a matrix or data frame of dummy variables into a factor.
  
  Function \code{Hill.N2} returns Hill's N2 values for species or samples for a given species by sites dataset (Hill 1973).

  Function \code{write.list.Excel} saves the data frames in a list object as a series of names worksheets in Excel format.
}

\value{
  \code{make.dummy} returns a matrix of dummay variables. \code{dummy2factor} returns a factor.

  \code{Hill.N2} returns a numeric vector of N2 values.
  
  \code{sp.summ} returns a matrix with columns for the number of occurences, Hill's N2 and maximum abundance of each species, and the number of occurences at abundance greater than the cut levels given in \code{n.cut}.

  \code{sam.summ} returns a matrix with columns for the number of taxa, Hill's N2, maximum value and site total of each site (sample), and the number of taxa in each site with abundance greater than the cut levels given in \code{max.cut}.
}

\references{
Hill, M.O. (1973) Diversity and evenness: a unifying notation and its consequences. \emph{Ecology}, \bold{54}, 427-432.
}

\author{ 
Steve Juggins
}

\keyword{ utilities }

==> rioja_0.8-7.tar.gz: rioja/man/utils.Rd <==
\name{utils}
\alias{make.dummy}
\alias{dummy2factor}
\alias{dot}
\alias{dot.default}
\alias{dot.data.frame}
\alias{Hill.N2}
\alias{site.summ}
\alias{sp.summ}
\alias{write.list.Excel}

\title{Utility functions. }
\description{
Utility functions to perform simple computations, transformations, formatting etc.
}
\usage{
make.dummy(fact)

dummy2factor(x)

Hill.N2(df, margin=2)

site.summ(y, max.cut=c(2, 5, 10, 20))

sp.summ(y, n.cut=c(5, 10, 20))

write.list.Excel(x, fName)

}
\arguments{
  \item{fact}{ a factor to convert to a matrix of dummy variables. }
  \item{x}{ a matrix or data frame of dummy variables to convert to a factor, 
        or a list to save as an Excel file. }
  \item{df}{ a data frame of species abundance data. }
  \item{margin}{ margin to calculate over: 1 = by rows, 2 = by columns. }
  \item{fName}{ file name for Excel file. }
  \item{y}{ data frame or matrix of species by sites data. }
  \item{n.cut}{ cut levels of abundance for species summary (see below). }
  \item{max.cut}{ cut levels of occurence for species sumamry. }
}

\details{
  Function \code{make.dummy} converts a factor into a matrix of dummy (1/0) variables. \code{dummy2factor} converts a matrix or data frame of dummy variables into a factor.
  
  Function \code{Hill.N2} returns Hill's N2 values for species or samples for a given species by sites dataset (Hill 1973).

  Function \code{write.list.Excel} saves the data frames in a list object as a series of names worksheets in Excel format.  Not that this function is only available on Windows.  See package \code{WriteXLS} for a Linux / MacOS X alternative.
}

\value{
  \code{make.dummy} returns a matrix of dummay variables. \code{dummy2factor} returns a factor.

  \code{Hill.N2} returns a numeric vector of N2 values.
  
  \code{sp.summ} returns a matrix with columns for the number of occurences, Hill's N2 and maximum abundance of each species, and the number of occurences at abundance greater than the cut levels given in \code{n.cut}.

  \code{sam.summ} returns a matrix with columns for the number of taxa, Hill's N2, maximum value and site total of each site (sample), and the number of taxa in each site with abundance greater than the cut levels given in \code{max.cut}.
}

\references{
Hill, M.O. (1973) Diversity and evenness: a unifying notation and its consequences. \emph{Ecology}, \bold{54}, 427-432.
}

\author{ 
Steve Juggins
}

\keyword{ utilities }
